[otrs-cvs] UnitTest/bin UnitTestAutoSetup.pl,1.249,1.250

"CVS commits notifications of OTRS.org" <[email protected]>
Newsgroups gmane.comp.otrs.cvs
Message-ID <[email protected]>
Comments:
Update of /home/cvs/UnitTest/bin
In directory lancelot:/tmp/cvs-serv23745/bin

Modified Files:
	UnitTestAutoSetup.pl 
Log Message:
Renamed profiles to reflect git migration.

Author: mg

Index: UnitTestAutoSetup.pl
===================================================================
RCS file: /home/cvs/UnitTest/bin/UnitTestAutoSetup.pl,v
retrieving revision 1.249
retrieving revision 1.250
diff -2 -u -d -r1.249 -r1.250
--- UnitTestAutoSetup.pl	20 Feb 2013 09:17:29 -0000	1.249
+++ UnitTestAutoSetup.pl	20 Feb 2013 14:57:14 -0000	1.250
@@ -49,9 +49,9 @@
 
     # ------------------------------------------------------------ #
     # OTRS 3.2.x CVS Framework
     # ------------------------------------------------------------ #
     {
         Profile   => 'otrs32',
-        Name      => 'OTRS 3.2.x CVS',
+        Name      => 'OTRS 3.2.x git',
         Framework => 'master',
         Packages  => [
@@ -61,9 +61,9 @@
 
     # ------------------------------------------------------------ #
     # OTRS 3.2.x CVS Framework + OrderManagement
     # ------------------------------------------------------------ #
     {
         Profile   => 'OTRSOrderManagement32',
-        Name      => 'OTRS 3.2.x CVS + internal OrderManagement',
+        Name      => 'OTRS 3.2.x git + internal OrderManagement',
         Framework => 'master',
         Packages  => [
@@ -80,9 +80,9 @@
 
     # ------------------------------------------------------------ #
     # OTRS 3.1.x CVS Framework
     # ------------------------------------------------------------ #
     {
         Profile   => 'otrs31',
-        Name      => 'OTRS 3.1.x CVS',
+        Name      => 'OTRS 3.1.x git',
         Framework => 'rel-3_1',
         Packages  => [
@@ -117,10 +117,10 @@
     # ------------------------------------------------------------ #
     # OTRS::ITSM 3.2.x CVS (Upgraded OTRS::ITSM 3.1.x)
     # (installs OTRS 3.2.x CVS + ForceInstalls ITSM 3.1.x
     # and then upgrades to ITSM 3.2.x)
     # ------------------------------------------------------------ #
     {
         Profile   => 'itsm32upgraded31',
-        Name      => 'ITSM 3.2.x CVS (OTRS 3.2.x CVS) upgraded from ITSM 3.1.x',
+        Name      => 'ITSM 3.2.x CVS (OTRS 3.2.x git) upgraded from ITSM 3.1.x',
         Framework => 'master',
         Packages  => [
@@ -225,5 +225,5 @@
     {
         Profile   => 'itsm32',
-        Name      => 'ITSM 3.2.x CVS (OTRS 3.2.x CVS)',
+        Name      => 'ITSM 3.2.x CVS (OTRS 3.2.x git)',
         Framework => 'master',
         Packages  => [
@@ -262,5 +262,5 @@
     {
         Profile   => 'itsm31',
-        Name      => 'ITSM 3.1.x CVS (OTRS 3.1.x CVS)',
+        Name      => 'ITSM 3.1.x CVS (OTRS 3.1.x git)',
         Framework => 'rel-3_1',
         Packages  => [
@@ -299,5 +299,5 @@
     {
         Profile   => 'faq22',
-        Name      => 'FAQ 2.2.x CVS (OTRS 3.2.x CVS)',
+        Name      => 'FAQ 2.2.x CVS (OTRS 3.2.x git)',
         Framework => 'master',
         Packages  => [
@@ -317,5 +317,5 @@
     {
         Profile   => 'faq21',
-        Name      => 'FAQ 2.1.x CVS (OTRS 3.1.x CVS)',
+        Name      => 'FAQ 2.1.x CVS (OTRS 3.1.x git)',
         Framework => 'rel-3_1',
         Packages  => [
@@ -334,5 +334,5 @@
     {
         Profile   => 'survey22',
-        Name      => 'Survey 2.2.x CVS (OTRS 3.2.x CVS)',
+        Name      => 'Survey 2.2.x CVS (OTRS 3.2.x git)',
         Framework => 'master',
         Packages  => [
@@ -351,5 +351,5 @@
     {
         Profile   => 'survey21',
-        Name      => 'Survey 2.1.x CVS (OTRS 3.1.x CVS)',
+        Name      => 'Survey 2.1.x CVS (OTRS 3.1.x git)',
         Framework => 'rel-3_1',
         Packages  => [
@@ -368,5 +368,5 @@
     {
         Profile   => 'timeaccounting21',
-        Name      => 'TimeAccounting 2.1.x CVS (OTRS 3.1.x CVS)',
+        Name      => 'TimeAccounting 2.1.x CVS (OTRS 3.1.x git)',
         Framework => 'rel-3_1',
         Packages  => [
@@ -385,5 +385,5 @@
     {
         Profile   => 'timeaccounting22',
-        Name      => 'TimeAccounting 2.2.x CVS (OTRS 3.2.x CVS)',
+        Name      => 'TimeAccounting 2.2.x CVS (OTRS 3.2.x git)',
         Framework => 'master',
         Packages  => [
---------------------------------------------------------------------
@@ -49,9 +49,9 @@
 
     # ------------------------------------------------------------ #
-    # OTRS 3.2.x CVS Framework
+    # OTRS 3.2.x git Framework
     # ------------------------------------------------------------ #
     {
@@ -61,9 +61,9 @@
 
     # ------------------------------------------------------------ #
-    # OTRS 3.2.x CVS Framework + OrderManagement
+    # OTRS 3.2.x git Framework + OrderManagement
     # ------------------------------------------------------------ #
     {
@@ -80,9 +80,9 @@
 
     # ------------------------------------------------------------ #
-    # OTRS 3.1.x CVS Framework
+    # OTRS 3.1.x git Framework
     # ------------------------------------------------------------ #
     {
@@ -117,10 +117,10 @@
     # ------------------------------------------------------------ #
     # OTRS::ITSM 3.2.x CVS (Upgraded OTRS::ITSM 3.1.x)
-    # (installs OTRS 3.2.x CVS + ForceInstalls ITSM 3.1.x
+    # (installs OTRS 3.2.x git + ForceInstalls ITSM 3.1.x
     # and then upgrades to ITSM 3.2.x)
     # ------------------------------------------------------------ #
OTRS mailing list: cvs-log - Webpage: http://otrs.org/
Archive: http://lists.otrs.org/pipermail/cvs-log
To unsubscribe: http://lists.otrs.org/cgi-bin/listinfo/cvs-log
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.